@@ -1,6 +1,6 @@
 /*
      This file is part of libmicrohttpd
-     (C) 2013 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2013 Christian Grothoff (and other contributing authors)
 
      This library is free software; you can redistribute it and/or
      modify it under the terms of the GNU Lesser General Public
@@ -574,7 +574,7 @@ process_upload_data (void *cls,
 	       uc->filename,
 	       strerror (errno));
       uc->response = internal_error_response;
-      close (uc->fd);
+      (void) close (uc->fd);
       uc->fd = -1;
       if (NULL != uc->filename)
 	{
@@ -690,8 +690,9 @@ generate_page (void *cls,
       ssize_t got;
       const char *mime;
 
-      if (0 != strcmp (method, MHD_HTTP_METHOD_GET))
-	return MHD_NO;  /* unexpected method (we're not polite...) */
+      if ( (0 != strcmp (method, MHD_HTTP_METHOD_GET)) &&
+           (0 != strcmp (method, MHD_HTTP_METHOD_HEAD)) )
+        return MHD_NO;  /* unexpected method (we're not polite...) */
       if ( (0 == stat (&url[1], &buf)) &&
 	   (NULL == strstr (&url[1], "..")) &&
 	   ('/' != url[1]))
@@ -783,7 +784,8 @@ generate_page (void *cls,
 	  return return_directory_response (connection);
 	}
     }
-  if (0 == strcmp (method, MHD_HTTP_METHOD_GET))
+  if ( (0 == strcmp (method, MHD_HTTP_METHOD_GET)) ||
+       (0 == strcmp (method, MHD_HTTP_METHOD_HEAD)) )
   {
     return return_directory_response (connection);
   }
