@@ -68,15 +68,19 @@
 #if defined(_WIN32)
 #ifndef _WIN32_WINNT
 #define _WIN32_WINNT 0x0501
-#else // _WIN32_WINNT
+#else /* _WIN32_WINNT */
 #if _WIN32_WINNT < 0x0501
 #error "Headers for Windows XP or later are required"
-#endif // _WIN32_WINNT < 0x0501
-#endif // _WIN32_WINNT
+#endif /* _WIN32_WINNT < 0x0501 */
+#endif /* _WIN32_WINNT */
 #ifndef WIN32_LEAN_AND_MEAN
 #define WIN32_LEAN_AND_MEAN 1
 #endif /* !WIN32_LEAN_AND_MEAN */
-#endif // _WIN32
+#endif /* _WIN32 */
+
+#if LINUX+0 && (defined(HAVE_SENDFILE64) || defined(HAVE_LSEEK64)) && ! defined(_LARGEFILE64_SOURCE)
+#define _LARGEFILE64_SOURCE 1
+#endif
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -94,7 +98,7 @@
 #undef HAVE_CONFIG_H
 #include <pthread.h>
 #define HAVE_CONFIG_H 1
-#endif // MHD_USE_POSIX_THREADS
+#endif /* MHD_USE_POSIX_THREADS */
 
 /* different OSes have fd_set in
    a broad range of header files;
@@ -150,8 +154,8 @@
 
 #if defined(_WIN32) && !defined(__CYGWIN__)
 #include <ws2tcpip.h>
-#define sleep(seconds) (SleepEx((seconds)*1000, 1)/1000)
-#define usleep(useconds) (void)SleepEx((useconds)/1000, 1)
+#define sleep(seconds) ((SleepEx((seconds)*1000, 1)==0)?0:(seconds))
+#define usleep(useconds) ((SleepEx((useconds)/1000, 1)==0)?0:-1)
 #endif
 
 #if !defined(SHUT_WR) && defined(SD_SEND)
@@ -167,7 +171,7 @@
 #if defined(_MSC_FULL_VER) && !defined (_SSIZE_T_DEFINED)
 #define _SSIZE_T_DEFINED
 typedef intptr_t ssize_t;
-#endif // !_SSIZE_T_DEFINED */
+#endif /* !_SSIZE_T_DEFINED */
 #ifndef MHD_SOCKET_DEFINED
 /**
  * MHD_socket is type for socket FDs
@@ -185,6 +189,12 @@ typedef SOCKET MHD_socket;
 #define MHD_SOCKET_DEFINED 1
 #endif /* MHD_SOCKET_DEFINED */
 
+#ifndef _WIN32
+typedef time_t _MHD_TIMEVAL_TV_SEC_TYPE;
+#else  /* _WIN32 */
+typedef long _MHD_TIMEVAL_TV_SEC_TYPE;
+#endif /* _WIN32 */
+
 /* Force don't use pipes on W32 */
 #if defined(_WIN32) && !defined(MHD_DONT_USE_PIPES)
 #define MHD_DONT_USE_PIPES 1
